% Implementation of SSC-OMP with fixed number of iterations
%
% The function uses the spectral clustering implementation by Ehsan Elhamifar
% from SSC_ADMM_v1.1 to ensure a fair comparison of the algorithms
% 
% X: m x N matrix of N data points
% smax: number of OMP iterations
% L: number of clusters
% labels: labels of the data points

function labels = OMPSSC(X,smax,L)
    N = size(X,2);
    m = size(X,1);
    C = zeros(N);
    
    for n = 1:N
       r = X(:,n);
       Xc = X;
       Xc(:,n) = nan;
       Xs = zeros(m,smax);
       lambda = zeros(smax,1);
       
       % OMP iterations
       for s = 1:smax
           [~,idx] = nanmax(abs(Xc'*r));
           if s == 1;
               xsp = Xc(:,idx)/sqrt(Xc(:,idx)'*Xc(:,idx));
           else
               xsp = Xc(:,idx) - Xs(:,1:(s-1))*(Xs(:,1:(s-1))'*Xc(:,idx));
               xsp = xsp/sqrt(xsp'*xsp);
           end
           r = r - xsp*(xsp'*r);
           Xs(:,s) = xsp;
           Xc(:,idx) = nan;
           lambda(s) = idx;
       end
       C(lambda,n) = X(:,lambda)\X(:,n);
    end
    
    C = abs(C);
    
    labels = SpectralClustering(C+C',L);
end