% This function implements the least squares version of the TSC algorithm 
% from the paper ``Robust subspace clustering via thresholding'' by
% Reinhard Heckel and Helmut B?lcskei
% 
% The function uses the spectral clustering implementation by Ehsan Elhamifar
% from SSC_ADMM_v1.1 to ensure a fair comparison of the algorithms
%
% X: m x N matrix of N data points
% q: input parameter of TSC
% L: number of clusters
% labels: labels of the data points
% Z: adjacency matrix 

function [labels,Z] = TSCb(X,q,L)

[~,N] = size(X);

Z = zeros(N,N);

for i=1:N
    corvec = abs(X'*X(:,i));
    corvec(i) = 0; % so TSC will not select it
    [~,order] = sort(corvec, 'descend');
    Z(i, order(1:q) ) = abs(pinv(X(:, order(1:q) ))*X(:,i));
end

Z = Z + Z';

% (normalized) spectral clustering step
% Use implementation from SSC_ADMM_v1.1
labels = SpectralClustering(Z,L);

end


