% Function to reproduce the figures in the paper "Dimensionality-
% reduced subspace clustering" by Reinhard Heckel, Michael Tschannen, and
% Helmut Boelcskei, 2015



function randProjSCphasetransAff(frac)

    addpath ./include/SSC_ADMM_v1.1/
    addpath ./include/TSC_OMP/
    
    s = RandStream('mcg16807','Seed',1);
    RandStream.setGlobalStream(s);
         
    % Simulation parameters
    m = 100;
    d = 10;
    L = 2;
    nl = 30;
    nrep = 5;
    prep = 5;
    
    if nargin < 1
        frac = 0;
    end

    alpha = 10;
    q = 6;
    smax = 4;
    
    ps = d./(0.32:0.03:1.24).^2;
    sigman = 0:0.05:1.5;

    cegtot = zeros(3,length(ps),length(sigman));
    ceftot = zeros(3,length(ps),length(sigman));
    
    for s = 1:length(sigman)
        
        ceg = zeros(3,length(ps));
        cef = zeros(3,length(ps));
        numerrs = 0;
        numprobinst = 0;
        
        
        for n = 1:nrep
            X = [];
            labels = [];

            % generate data set
            if frac == 0
                UC = orth(randn(m,d*L));
            else
                UC = orth(randn(m,d*frac));
            end
            
            for l=1:L
                if frac == 0
                    U = UC(:,((l-1)*d+1):(l*d));
                else
                    U = orth([UC,randn(m,d*(1-frac))] );
                end
                
                A = normc(randn(d,nl));
                X = [X U*A];
                labels = [labels ones(1,nl)*l];
            end

            if sigman(s) > 0
                X = X + sigman(s)*randn(size(X))/sqrt(m);
            end


            % test algorithms
            for p = 1:prep
                try
                    [cg, cf,~,~] = testSCAlgos(X,labels,round(ps),alpha,q,smax);

                    ceg = ceg + cg;
                    cef = cef + cf;

                    numprobinst = numprobinst + 1;

                    fprintf('n: %i, p: %i \n',n,p)
                catch
                    numerrs = numerrs + 1;
                end
            end
        end
    
        cegtot(:,:,s) = ceg/numprobinst;
        ceftot(:,:,s) = cef/numprobinst;
        
    end
    
    fprintf('There were %i error(s) during this simulation \n',numerrs);
    
    saveheatmap(squeeze(cegtot(1,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthGRP_SSC_',num2str(frac,'%.2f'),'.dat'))
    saveheatmap(squeeze(cegtot(2,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthGRP_TSC_',num2str(frac,'%.2f'),'.dat'))
    saveheatmap(squeeze(cegtot(3,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthGRP_SSC-OMP_',num2str(frac,'%.2f'),'.dat'))
    
    saveheatmap(squeeze(cegtot(1,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthFRP_SSC_',num2str(frac,'%.2f'),'.dat'))
    saveheatmap(squeeze(cegtot(2,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthFRP_TSC_',num2str(frac,'%.2f'),'.dat'))
    saveheatmap(squeeze(cegtot(3,:,:)),sqrt(d./ps),sigman,strcat('PhaseSynthFRP_SSC-OMP_',num2str(frac,'%.2f'),'.dat'))

end